Summary:        The PARI/GP free computer algebra system
Name:           pari
Version:        2.7.6
Release:        1%{?dist}%{?pext}
License:        GPL
Group:          Applications/Engineering
Source0:        ftp://%{name}.math.u-bordeaux.fr/pub/%{name}/unix/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
Patch0:         %{name}-2.7.1-build.patch
URL:            http://%{name}.math.u-bordeaux.fr/
Buildroot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:         Karim Belabas <karim.belabas@math.u-bordeaux.fr>
Requires:       %{name}-libs = %{version}-%{release}
Requires:       gzip %{_bindir}/xdvi
BuildRequires:  desktop-file-utils tetex tetex-dvips
BuildRequires:  gmp-devel ncurses-devel readline-devel
BuildRequires:  libX11-devel

%description
PARI/GP is a widely used computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic curves...),
but also contains a large number of other useful functions to compute with
mathematical entities such as matrices, polynomials, power series, algebraic
numbers etc., and a lot of transcendental functions. This package provides gp,
an easy-to-use interactive shell giving access to the PARI functions.


%package        devel
Summary:        Development tools for PARI/GP
Group:          Development/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Requires:       gmp-devel ncurses-devel readline-devel
Obsoletes:      libpari-devel < %{version}-%{release}

%description    devel
The %{name}-devel package contains the libraries and header files for developing
software using PARI/GP.


%package        doc
Summary:        Documentation for PARI/GP
Group:          Documentation
%{?!el5:BuildArch: noarch}

%description    doc
PARI/GP is a widely used computer algebra system designed for fast computations
in number theory. This package contains its documentation in PDF and HTML format.


%package        libs
Summary:        The PARI/GP core library
Group:          System Environment/Libraries
Obsoletes:      libpari < %{version}-%{release}
Obsoletes:      %{name}-lib < %{version}-%{release}

%description    libs
The %{name}-libs package contains the core runtime library for PARI/GP.


%package        static
Summary:        Static libraries for PARI/GP
Group:          Development/Libraries
Requires:       %{name}-devel = %{version}-%{release}

%description    static
The %{name}-static package contains the statically linkable libraries for
PARI/GP.


%prep
%setup -q
%patch0 -p1


%build
export CFLAGS="${RPM_OPT_FLAGS} -fPIC -Wno-unused"

export Xincroot="%{_includedir}/X11"
export X11="%{_libdir}"

./Configure \
	--prefix=%{_prefix}             \
	--libdir=%{_libdir}             \
	--sysdatadir=%{_libdir}/%{name} \
	--mandir=%{_mandir}/man1        \
	--kernel=gmp                    \
	--graphic=X11                   \
	--mt=pthread                    \
	--enable-tls                    \
	--with-readline                 \
	--with-gmp

%{__make} %{?_smp_mflags} \
	all

# Build static library
pushd Olinux-*
%{__make} lib-sta
popd

# Build documentation
pushd doc
%{__make} html

for FILE in *.dvi; do
  %{__make} `basename ${FILE} .dvi`.pdf
done
popd


%check
%{__make} bench

# Extra tests
for TEST in compat intnum qfbsolve rfrac round4 stark; do
  %{__make} dotest-${TEST}
done


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_prefix}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/applications

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

desktop-file-install --vendor="%{name}"     \
	--dir=${RPM_BUILD_ROOT}%{_datadir}/applications %{SOURCE1}

# Install static library
pushd Olinux-*
%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install-lib-sta
popd

# Cleanup
%{__rm} -f ${RPM_BUILD_ROOT}%{_libdir}/lib*.so.?


%post libs -p /sbin/ldconfig


%postun libs -p /sbin/ldconfig


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc AUTHORS CHANGES* COMPAT COPYING
%doc INSTALL MACHINES NEW README*
%{_bindir}/gp
%{_bindir}/gp-*
%{_bindir}/gphelp
%{_bindir}/tex2mail
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}
%{_mandir}/man1/*.1*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/libpari.so
%{_libdir}/%{name}

%files doc
%defattr(-,root,root)
%doc doc/*.{html,pdf}

%files libs
%defattr(-,root,root)
%{_libdir}/libpari-gmp*.so.*

%files static
%defattr(-,root,root)
%{_libdir}/libpari.a


%changelog
* Tue Sep 27 2016 Peter Pramberger <peterpramb@member.fsf.org> - 2.7.6-1
- New version (2.7.6)

* Sat Jan 02 2016 Peter Pramberger <peterpramb@member.fsf.org> - 2.7.5-1
- New version (2.7.5)

* Sat Jul 11 2015 Peter Pramberger <peterpramb@member.fsf.org> - 2.7.4-1
- New version (2.7.4)

* Fri May 08 2015 Peter Pramberger <peterpramb@member.fsf.org> - 2.7.3-1
- New version (2.7.3)

* Wed Oct 01 2014 Peter Pramberger <peterpramb@member.fsf.org> - 2.7.2-1
- New version (2.7.2)

* Fri Jul 25 2014 Peter Pramberger <peterpramb@member.fsf.org> - 2.7.1-1
- New version (2.7.1)

* Mon May 20 2013 Peter Pramberger <peterpramb@member.fsf.org> - 2.5.4-1
- New version (2.5.4)

* Sat Sep 22 2012 Peter Pramberger <peterpramb@member.fsf.org> - 2.5.2-1
- New version (2.5.2)

* Mon Mar 19 2012 Peter Pramberger <peterpramb@member.fsf.org> - 2.5.1-1
- New version (2.5.1)

* Fri Sep 09 2011 Peter Pramberger <peterpramb@member.fsf.org> - 2.5.0-1
- New version (2.5.0)

* Wed Feb 17 2010 Peter Pramberger <peterpramb@member.fsf.org> - 2.3.5-1
- New version (2.3.5)

* Thu Jul 02 2009 Peter Pramberger <peterpramb@member.fsf.org> - 2.3.4-1
- Initial build
